# surfsci

A suite of tools for handling surface science related data. This project will contain tools for the following: 

* X-ray photoelectron spectroscopy (XPS)

## Future

* Docmuentation (priority)
* X-ray diffraction (XRD)
* Magnetron sputter deposition

